# eric7.Plugins.VcsPlugins.vcsGit.GitCommitDialog

Module implementing a dialog to enter the commit message.

### Global Attributes

None

### Classes

GitCommitDialog | Class implementing a dialog to enter the commit message.

### Functions

None

## GitCommitDialog

Class implementing a dialog to enter the commit message.

### Signals

accepted()
  emitted, if the dialog was accepted
rejected()
  emitted, if the dialog was rejected

### Derived from

QWidget, Ui_GitCommitDialog

### Class Attributes

None

### Class Methods

None

### Methods

GitCommitDialog | Constructor
amend | Public method to retrieve the state of the amend flag.
logMessage | Public method to retrieve the log message.
on_buttonBox_accepted | Private slot called by the buttonBox accepted signal.
on_buttonBox_clicked | Private slot called by a button of the button box clicked.
on_buttonBox_rejected | Private slot called by the buttonBox rejected signal.
on_recentComboBox_activated | Private slot to select a commit message from recent ones.
resetAuthor | Public method to retrieve the state of the reset author flag.
showEvent | Protected method called when the dialog is about to be shown.
stagedOnly | Public method to retrieve the state of the staged only flag.

### Static Methods

None

#### GitCommitDialog (Constructor)

GitCommitDialog(vcs, msg, amend, commitAll, parent=None)

Constructor

vcs
  reference to the vcs object
msg
  initial message (string)
amend
  flag indicating to amend the HEAD commit (boolean)
commitAll
  flag indicating to commit all local changes (boolean)
parent
  parent widget (QWidget)

#### GitCommitDialog.amend

amend()

Public method to retrieve the state of the amend flag.

Return:
  state of the amend flag (boolean)

#### GitCommitDialog.logMessage

logMessage()

Public method to retrieve the log message.

Return:
  the log message (string)

#### GitCommitDialog.on_buttonBox_accepted

on_buttonBox_accepted()

Private slot called by the buttonBox accepted signal.

#### GitCommitDialog.on_buttonBox_clicked

on_buttonBox_clicked(button)

Private slot called by a button of the button box clicked.

button
  button that was clicked (QAbstractButton)

#### GitCommitDialog.on_buttonBox_rejected

on_buttonBox_rejected()

Private slot called by the buttonBox rejected signal.

#### GitCommitDialog.on_recentComboBox_activated

on_recentComboBox_activated(index)

Private slot to select a commit message from recent ones.

index (int)
  index of the selected entry

#### GitCommitDialog.resetAuthor

resetAuthor()

Public method to retrieve the state of the reset author flag.

Return:
  state of the reset author flag (boolean)

#### GitCommitDialog.showEvent

showEvent(evt)

Protected method called when the dialog is about to be shown.

evt
  the event (QShowEvent)

#### GitCommitDialog.stagedOnly

stagedOnly()

Public method to retrieve the state of the staged only flag.

Return:
  state of the staged only flag (boolean)

Up